@@ -236,7 +236,7 @@ public class Gridder  {
 	    
 	    double lon = qlon;
 	    
-	    if (lon > 360) {
+	    if (lon >= 360) {
 		lon -= 360;
 	    }
 	    
@@ -249,8 +249,12 @@ public class Gridder  {
 		    setLabel(null);
 		}
 	    } else {
-		fm.setSeparators(new String[]{"\u00B0", "'", "\""});
-	        setLabel(fm.format(lon, lonPrec));
+		if (Math.abs(lon-360) > 1.e-8) {
+		    fm.setSeparators(new String[]{"\u00B0", "'", "\""});
+	            setLabel(fm.format(lon, lonPrec));
+                } else {
+                    setLabel(null);
+                }
 	    }
 	    // The lines of longitude that we tend to choose for
 	    // drawing are likely to be ones that touch singularities
@@ -265,6 +269,12 @@ public class Gridder  {
 	    drawLine(lon-1.e-10, lon-1.e-10, latLimits[0],latLimits[1]);
 	}
 	for (double lat=latValues[0]; lat <= latLimits[1]; lat += latValues[1]) {
+            System.err.println("Lat is:"+lat);
+            if (Math.abs(Math.abs(lat)-90) < 1.e-5) {
+                // Don't draw lines at 90 degrees latitude.
+                System.err.println("Skipping lat 90");
+                continue;
+            }
 	    fm.setSeparators(new String[]{"\u00B0", "'", "\""});
 	    setLabel(fm.format(lat, latPrec));
 	    drawLine(lonLimits[0], lonLimits[1], lat, lat);
