@@ -495,6 +495,18 @@ public class Imager {
 	    
 	int count = 1;
 	for (String surv: survs) {
+            String survLc = surv.toLowerCase();
+            if (survLc.equals("average")) {
+                if (survs.length != 3  || !Settings.has("rgb")) {
+                    throw new IllegalArgumentException("Error:  Invalid use of 'Average' survey.");
+                }
+                if (count == 3) {
+                    new IJProcessor().generateRGB();
+                }
+                count += 1;
+                continue;
+            }
+                
 	    if (survs.length > 1) {
 		updateOutput(output, count);
 	    }
