@@ -32,13 +32,13 @@ public class LI extends skyview.geometry.Sampler {
         if (x < 0 || x > inWidth-1 || y < 0 || y > inHeight-1) {
 	    return;
 	} else {
-	    int ix = (int) Math.floor(x);
-	    int iy = (int) Math.floor(y);
+	    long ix = (int) Math.floor(x);
+	    long iy = (int) Math.floor(y);
 	    double dx = x-ix;
 	    double dy = y-iy;
 	
 	    for (int k=0; k < inDepth; k += 1) {
-	        int inOffset = k*inWidth*inHeight;
+	        long inOffset = k*(long)inWidth*(long)inHeight;
 		int outOffset = k*outWidth*outHeight;
 	
 	        outImage.setData(pix+outOffset,  
