@@ -64,6 +64,8 @@ import java.util.HashSet;
 public class IJProcessor implements skyview.process.Processor {
     
     private static ImageStack[] rgb = new ImageStack[3];
+    private static int lastHeight, lastWidth;
+    private static String lastStem;
     
     private static ArrayList<ImagePlus> savedImages;
     
@@ -316,8 +318,7 @@ public class IJProcessor implements skyview.process.Processor {
 	}
     }
     
-    private void processGrid(String gridStr) {
-	
+    private void processGrid(String gridStr) {	
 	
 	if (gridStr != null) {
 	    
@@ -389,7 +390,9 @@ public class IJProcessor implements skyview.process.Processor {
 
     private boolean processRGB(String rgbStr, String outStem, int index) {
 	if (rgbStr != null) {
-	    
+            lastWidth  = output.getWidth();
+            lastHeight = output.getHeight();
+            lastStem   = outStem;
 	    if (Settings.has("rgboffset")) {
 		try {
 		    String[] offset = Settings.getArray("rgboffset");
@@ -428,24 +431,7 @@ public class IJProcessor implements skyview.process.Processor {
 	        rgb[index]      = new ImagePlus(surveys[index], ip).getStack();
 		
 	        if (index == 2 || index == surveys.length-1) {
-		    
-		    RGBStackMerge rsm = new RGBStackMerge();
-		    ImageStack is   = rsm.mergeStacks(output.getWidth(), output.getHeight(), 1,
-						    rgb[0], rgb[1], rgb[2], true);
-		    ImagePlus imp   = new ImagePlus("rgb", is);
-		    if (Settings.has("quicklook") ) {
-                        // Get rid of .fit or .fits at the end
-                        //System.out.println("Starting with: "+outStem);
-                        String filename = outStem.replaceAll("\\.fits?$", "");
-                        // Now get rid of a terminal _\d+
-                        filename = filename.replaceAll("_\\d+$", "");
-                        filename += "_rgb.jpg";
-	                new FileSaver(imp).saveAsJpeg(filename);
-		        System.err.println("  Writing 3-color image: "+filename);
-		    }
-		    if (Settings.has("imagej")) {
-			showImp(imp);
-		    }
+                    generateRGB();		    
 	        }
 	    }
 	    return true;
@@ -453,6 +439,110 @@ public class IJProcessor implements skyview.process.Processor {
 	return false;
     }
     
+    public void generateRGB() {
+        RGBStackMerge rsm = new RGBStackMerge();
+        
+        String[] surveys = Settings.getArray("survey");
+        int avgIndex = -1;
+        if (surveys.length == 3) {
+            boolean found = false;
+            for (int i=0; i<surveys.length; i += 1) {
+                String surv = surveys[i];
+                if (surv.toLowerCase().equals("average")) {
+                    if (found) {
+                        throw new IllegalArgumentException("Multiple Average surveys in RGB");
+                    }
+                    found = true;
+                    avgIndex = i;
+                }
+            }
+        }
+        if (avgIndex >= 0) {
+            int bot = -1;
+            int top = -1;
+            for (int i=0; i<3; i += 1) {
+                if (i != avgIndex) {
+                    if (bot < 0) {
+                        bot = i;
+                    } else {
+                        top = i;
+                    }
+                }
+            }
+            
+            byte[] d1 = (byte[]) rgb[bot].getProcessor(1).getPixels();
+            byte[] d2 = (byte[]) rgb[top].getProcessor(1).getPixels();
+            byte[] d3 = new byte[d1.length];
+            for (int i=0; i<d1.length; i += 1) {
+                int v1 =  d1[i];
+                int v2 =  d2[i];
+                if (v1 < 0) v1 += 256;
+                if (v2 < 0) v2 += 256;
+                d3[i] = (byte) ((v1+v2)/2);                
+            }
+            
+            ByteProcessor myIp = new ByteProcessor(lastWidth, lastHeight, d3);
+            rgb[avgIndex]     = new ImagePlus("Avg", myIp).getStack();            
+        }
+        
+        if (Settings.has("whiten")) {
+            whitenImages();
+        }
+        
+        String outStem = lastStem;
+        ImageStack is  = rsm.mergeStacks(lastWidth, lastHeight, 1,
+			rgb[0], rgb[1], rgb[2], true);
+	ImagePlus imp   = new ImagePlus("rgb", is);
+	if (Settings.has("quicklook") ) {
+            // Get rid of .fit or .fits at the end
+            String filename = outStem.replaceAll("\\.fits?$", "");
+            // Now get rid of a terminal _\d+
+            filename = filename.replaceAll("_\\d+$", "");
+            filename += "_rgb.jpg";
+	    new FileSaver(imp).saveAsJpeg(filename);
+        }
+        if (Settings.has("imagej")) {
+	    showImp(imp);
+        }
+    }
+    
+    void whitenImages() {
+        String[] fields = Settings.getArray("whiten");
+        // Points in range at which histograms are to match
+        double low = 0.05;
+        double high = 0.5;
+        
+        System.err.println("Got fields:"+fields.length+" "+Settings.get("whiten"));
+        
+                
+        if (fields.length > 1  || fields[0].length() > 0) {
+            
+            try {
+                low = Double.parseDouble(fields[0]);
+                high = Double.parseDouble(fields[1]);
+            } catch (Exception e) {
+                System.err.println("Invalid Whiten values:"+Settings.get("whiten"));
+                return;
+            }
+        }
+        skyview.util.HistoMatcher matcher = new skyview.util.HistoMatcher(low,high);
+        int count = 0;
+        for (int i=0; i<rgb.length; i += 1) {
+            ImageStack st = rgb[i];
+            if (st != null) {
+                System.err.println("Getting data:"+i);
+                byte[] data = (byte[]) st.getProcessor(1).getPixels();
+                count += 1;
+                matcher.addList(data);                
+            }
+        }
+        matcher.calc();
+        for (int i=0; i<count; i += 1) {
+            System.err.println("Rescaling:"+i);
+            matcher.rescale(i);            
+        }
+    }
+    
     void setColor(String colorString) {
 	ip.plotStrings();
 	Color col = getColor(colorString);
