@@ -24,7 +24,8 @@ public class DSSImageFactory implements ImageFactory {
 	  try {
 	       return new DSSImage(file);
 	  } catch (Exception e) {
-	      System.err.println("Got exception on file:"+file+"\nException:"+e);
+	      System.err.println("DSS Error: Got exception on file:"+file+"\nException:"+e);
+              e.printStackTrace(System.err);
 	      return null;
 	  }
     }
