@@ -1050,7 +1050,7 @@ public class BasicTester {
 	}
 	base += 1;
 	
-	Settings.put("catalog", "http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+	Settings.put("catalog", "https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
 	if (base >= minTest && base <= maxTest) {
 	    Imager.getImager().clearImageCache();
 	    runImagerx(base);
@@ -1063,7 +1063,7 @@ public class BasicTester {
 	base += 1;
 	
 	// This should reuse requests
-	Settings.put("catalog", "ned,I/284,http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+	Settings.put("catalog", "ned,I/284,https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
 	if (base >= minTest && base <= maxTest) {
 	    Imager.getImager().clearImageCache();
 	    runImagerx(base);
@@ -1075,7 +1075,7 @@ public class BasicTester {
 	}
 	base += 1;
 	
-	Settings.put("catalog", "ned,I/284,http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+	Settings.put("catalog", "ned,I/284,https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
 	// Repeat after clearing requests.
 	skyview.vo.CatalogProcessor.clearRequests();
 	if (base >= minTest && base <= maxTest) {
