@@ -89,12 +89,14 @@ import nom.tam.util.ArrayFuncs;
  * the test is run, this file can be concatenated to the comparison.settings (in
  * the source area) for future regression testing.
  */
+
+
 public class NewTester {
 
     private static FileWriter os;
     private static boolean    first = true;
     
-    /** min/maxTest may be overriden by the logical variables MIN_TEST and MAX_TEST */
+    /** min/maxTest may be overridden by the logical variables MIN_TEST and MAX_TEST */
     private static String minTest = "0";
     private static String maxTest = "999999";
     
@@ -214,7 +216,13 @@ public class NewTester {
             "EBHIS",
             "TGSS ADR1", 
             "AKARI N60", "AKARI WIDE-S", "AKARI WIDE-L", "AKARI N160",
-	    "HI4PI"
+	    "HI4PI", 
+            "UVOT V Intensity", "UVOT B Intensity", "UVOT U Intensity", "UVOT UVW1 Intensity",
+            "UVOT UVM2 Intensity", "UVOT UVW2 Intensity",
+            "UVOT V Counts", "UVOT B Counts", "UVOT U Counts", "UVOT UVW1 Counts",
+            "UVOT UVM2 Counts", "UVOT UVW2 Counts",
+            "UVOT V Exposure", "UVOT B Exposure", "UVOT U Exposure", "UVOT UVW1 Exposure",
+            "UVOT UVM2 Exposure", "UVOT UVW2 Exposure"
         };
 
         // Mellinger survey is done twice so that
@@ -253,6 +261,8 @@ public class NewTester {
             "GOODS: VLT ISAAC J", "GOODS: VLT ISAAC H", "GOODS: VLT ISAAC Ks",
             "HUDF: VLT ISAAC Ks", "CDFS: LESS"
         };
+        
+        String[] ultravistas = {"Ultravista-h", "Ultravista-j", "Ultravista-ks"};
 
 
         // This set of surveys
@@ -403,6 +413,17 @@ public class NewTester {
                 test(true);
             }
         }
+        base.up();
+        base.down();
+        // Ultravista region (COSMOS?)
+        currentSettings.put("Position","150.00,2.2");
+        currentSettings.put("Size", "0.02");
+        currentSettings.put("Pixels", "400");
+        for (String survey: ultravistas) {
+            currentSettings.put("survey", survey);
+            test(true);
+        }
+
     }
 
     public int jpegSum(String jpegName) throws Exception {
